@@ -122,9 +122,9 @@ def _read_data(stream, ostr1, ostr2):
             data = data.decode(sys.stdout.encoding)
         if data:
             ostr1.write(data)
-            #ostr2.write(data)
+            ostr2.write(data)
             ostr1.flush()
-            #ostr2.flush()
+            ostr2.flush()
         else:
             break
 
@@ -279,7 +279,7 @@ def run_command(cmd, outfile=None, cwd=None, ostream=None, stdin=None, stdout=No
         # Ignore IOErrors, which are caused by interupts
         #
         pass
-    if ostream is None or outfile is not None:
+    if ostream is None and outfile is not None:
         stdout_arg.close()
     elif not tmpfile is None and not ignore_output:
         tmpfile.seek(0)
