@@ -15,29 +15,24 @@ class Test(unittest.TestCase):
 
     def test_foo(self):
         if not subprocess.mswindows:
-            #foo = SubprocessMngr("ls *py > /tmp/.pyutilib", shell=True)
-            #foo.wait()
-            #print ""
-
             foo = SubprocessMngr("ls *py > /tmp/.pyutilib", stdout=subprocess.PIPE, shell=True)
-            #for line in foo.process.stdout:
-                #print line,
-            print ""
+            foo.wait()
+            print("")
             if os.path.exists("/tmp/.pyutilib"):
                 os.remove("/tmp/.pyutilib")
         else:
             foo = SubprocessMngr("cmd /C \"dir\" > C:/tmp", shell=True)
             foo.wait()
-            print ""
+            print("")
 
         stime = timer()
         # On MS Windows, do not run this in a shell.  If so, MS Windows has difficulty
         # killing the process after the timelimit
-        print "Subprocess python process"
+        print("Subprocess python process")
         sys.stdout.flush()
         foo = SubprocessMngr("python -q -c \"while True: pass\"", shell=not subprocess.mswindows)
         foo.wait(5)
-        print "Ran for " + `timer()-stime` + " seconds"
+        print("Ran for %f seconds" % (timer()-stime))
 
     @unittest.skipIf(subprocess.mswindows, "Cannot test the use of 'memmon' on MS Windows")
     @unittest.skipIf(pyutilib.services.registered_executable('memmon') is None, "The 'memmon' executable is not available.")
@@ -50,6 +45,7 @@ class Test(unittest.TestCase):
             flag = line.startswith('memmon:')
             if flag:
                 break
+        INPUT.close()
         if not flag:
             self.fail("Failed to properly execute 'memmon' with the 'ls' command")
         os.remove(currdir+'ls.out')
@@ -65,6 +61,7 @@ class Test(unittest.TestCase):
             flag = 'Memcheck' in line
             if flag:
                 break
+        INPUT.close()
         if not flag:
             self.fail("Failed to properly execute 'valgrind' with the 'ls' command")
         os.remove(currdir+'valgrind.out')
